Welcome to dartmouth_auth's documentation!
==========================================

**dartmouth_auth** is a lightweight Python package facilitating authentication for Dartmouth services.

It currently consists of a single function you can use to obtain an authentication token if you have a valid Dartmouth API key.

.. toctree::
   :maxdepth: 2

   usage
   api
